# 翻译管理系统 - 管理后台

一个基于 Nuxt 3 和 Supabase 构建的现代化翻译管理系统后台。

## ✨ 功能特性

- 🔐 **安全认证**：支持多种密码加密方式（明文/bcrypt）
- 📊 **数据统计**：实时显示用户、订单、收入等关键指标
- 👥 **用户管理**：完整的用户信息管理功能
- 📱 **响应式设计**：适配各种设备屏幕
- 🎨 **现代UI**：基于 Tailwind CSS 的美观界面

## 🛠️ 技术栈

- **前端框架**：Nuxt 3
- **UI框架**：Tailwind CSS
- **状态管理**：Pinia
- **数据库**：Supabase (PostgreSQL)
- **认证**：自定义认证系统
- **开发工具**：Vite, TypeScript

## 🚀 快速开始

### 环境要求

- Node.js 16.x 或更高版本
- npm 或 yarn

### 安装依赖

```bash
npm install
```

### 环境配置

创建 `.env` 文件并配置以下环境变量：

```env
SUPABASE_URL=your_supabase_url
SUPABASE_ANON_KEY=your_supabase_anon_key
```

### 启动开发服务器

```bash
npm run dev
```

访问 `http://localhost:3000` 查看应用。

## 🔑 管理员账户

系统提供以下测试管理员账户：

1. **账户1**：`test@admin.com` / `123456`
2. **账户2**：`admin@example.com` / `admin123`

## 📁 项目结构

```
interpreter-admin/
├── assets/          # 静态资源
├── components/      # Vue 组件
├── composables/     # 组合式函数
├── layouts/         # 布局文件
├── middleware/      # 路由中间件
├── pages/          # 页面文件
├── plugins/        # 插件
├── public/         # 公共文件
└── server/         # 服务端代码
```

## 🔧 主要功能模块

### 认证系统
- 支持多种密码加密方式
- 安全的会话管理
- 自动登录状态检查

### 仪表板
- 实时数据统计
- 最近活动展示
- 快速操作入口

### 用户管理
- 用户信息查看
- 权限管理
- 状态控制

## 🚀 部署

### 构建生产版本

```bash
npm run build
```

### 预览生产版本

```bash
npm run preview
```

## 🤝 贡献指南

1. Fork 本仓库
2. 创建特性分支 (`git checkout -b feature/AmazingFeature`)
3. 提交更改 (`git commit -m 'Add some AmazingFeature'`)
4. 推送到分支 (`git push origin feature/AmazingFeature`)
5. 开启 Pull Request

## 📝 更新日志

### v1.0.0 (2024-01-XX)
- ✅ 初始版本发布
- ✅ 基础认证系统
- ✅ 管理员仪表板
- ✅ 响应式设计

## 📄 许可证

本项目采用 MIT 许可证 - 查看 [LICENSE](LICENSE) 文件了解详情。

## 🆘 支持

如果您遇到任何问题或有建议，请通过以下方式联系：

- 创建 Issue
- 发送邮件至项目维护者

---

**开发团队** | 万众科技 | 2024
