// https://nuxt.com/docs/api/configuration/nuxt-config
export default defineNuxtConfig({
  compatibilityDate: '2025-05-15',
  devtools: { enabled: true },
  
  // 配置SSR
  ssr: true,
  
  // 配置水合策略
  experimental: {
    payloadExtraction: false
  },
  
  // 应用配置
  app: {
    head: {
      viewport: 'width=device-width,initial-scale=1',
      charset: 'utf-8'
    }
  },
  
  // CSS配置
  css: ['~/assets/css/main.css'],
  
  // 模块配置
  modules: [
    '@nuxtjs/tailwindcss',
    '@pinia/nuxt',
    '@vueuse/nuxt',
    '@nuxtjs/supabase'
  ],

  // Vite配置 - 修复WebSocket连接问题
  vite: {
    server: {
      hmr: {
        port: 3000,
        clientPort: 3000
      }
    }
  },

  // 开发服务器配置
  devServer: {
    port: 3000,
    host: 'localhost'
  },

  // Supabase配置
  supabase: {
    url: process.env.SUPABASE_URL || 'https://riwtulmitqioswmgwftg.supabase.co',
    key: process.env.SUPABASE_ANON_KEY || 'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpc3MiOiJzdXBhYmFzZSIsInJlZiI6InJpd3R1bG1pdHFpb3N3bWd3ZnRnIiwicm9sZSI6ImFub24iLCJpYXQiOjE3NDg1OTc1ODgsImV4cCI6MjA2NDE3MzU4OH0.fxSW_uEbpR1zwepjb83DIUIwTrmsboK2nTjPpS6XMtw',
    // 禁用自动重定向
    redirect: false
  },

  // 运行时配置
  runtimeConfig: {
    // 公共环境变量（客户端和服务器端都可用）
    public: {
      supabaseUrl: process.env.SUPABASE_URL || 'https://riwtulmitqioswmgwftg.supabase.co',
      supabaseAnonKey: process.env.SUPABASE_ANON_KEY || 'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpc3MiOiJzdXBhYmFzZSIsInJlZiI6InJpd3R1bG1pdHFpb3N3bWd3ZnRnIiwicm9sZSI6ImFub24iLCJpYXQiOjE3NDg1OTc1ODgsImV4cCI6MjA2NDE3MzU4OH0.fxSW_uEbpR1zwepjb83DIUIwTrmsboK2nTjPpS6XMtw'
    }
  }
})
